Enum Snthr
#[repr(u8)]pub enum Snthr {
Show 16 variants
NoisePlus35 = 0,
NoisePlus60 = 1,
NoisePlus95 = 2,
NoisePlus12 = 3,
NoisePlus156 = 4,
NoisePlus18 = 5,
NoisePlus216 = 6,
NoisePlus241 = 7,
NoisePlus276 = 8,
NoisePlus301 = 9,
_RESERVED_a = 10,
_RESERVED_b = 11,
_RESERVED_c = 12,
_RESERVED_d = 13,
_RESERVED_e = 14,
_RESERVED_f = 15,
}Expand description
SNTHR. This bitfield is set and cleared by software. It is used to select the gain to be applied at CIC output. If the application attempts to write a new gain value while the previous one is not yet applied, this new gain value is ignored. Reading back this bitfield informs the application on the current gain value.
Variants
NoisePlus35 = 0
Threshold is 3.5 dB higher than ANLVL
NoisePlus60 = 1
Threshold is 6.0 dB higher than ANLVL
NoisePlus95 = 2
Threshold is 9.5 dB higher than ANLVL
NoisePlus12 = 3
Threshold is 12 dB higher than ANLVL
NoisePlus156 = 4
Threshold is 15.6 dB higher than ANLVL
NoisePlus18 = 5
Threshold is 18 dB higher than ANLVL
NoisePlus216 = 6
Threshold is 21.6 dB higher than ANLVL
NoisePlus241 = 7
Threshold is 24.1 dB higher than ANLVL
NoisePlus276 = 8
Threshold is 27.6 dB higher than ANLVL
NoisePlus301 = 9
Threshold is 30.1 dB higher than ANLVL
_RESERVED_a = 10
_RESERVED_b = 11
_RESERVED_c = 12
_RESERVED_d = 13
_RESERVED_e = 14
_RESERVED_f = 15
Implementations